From d002e3da008ec6945a405e4f14941bd42a341494 Mon Sep 17 00:00:00 2001
From: zeripath <art27@cantab.net>
Date: Wed, 1 Jun 2022 04:06:31 +0100
Subject: [PATCH] Fix spelling mistake in ProcReceive (#19853)

There was a spelling mistake in the ProcReceive handler. This PR fixes
this.
---
 routers/private/hook_proc_receive.go | 2 +-
 services/agit/agit.go                | 4 ++--
 2 files changed, 3 insertions(+), 3 deletions(-)

diff --git a/routers/private/hook_proc_receive.go b/routers/private/hook_proc_receive.go
index e427a55c56..81dbc1fd18 100644
--- a/routers/private/hook_proc_receive.go
+++ b/routers/private/hook_proc_receive.go
@@ -23,7 +23,7 @@ func HookProcReceive(ctx *gitea_context.PrivateContext) {
 		return
 	}
 
-	results := agit.ProcRecive(ctx, opts)
+	results := agit.ProcReceive(ctx, opts)
 	if ctx.Written() {
 		return
 	}
diff --git a/services/agit/agit.go b/services/agit/agit.go
index 2889236181..cc520dbc76 100644
--- a/services/agit/agit.go
+++ b/services/agit/agit.go
@@ -20,8 +20,8 @@ import (
 	pull_service "code.gitea.io/gitea/services/pull"
 )
 
-// ProcRecive handle proc receive work
-func ProcRecive(ctx *context.PrivateContext, opts *private.HookOptions) []private.HookProcReceiveRefResult {
+// ProcReceive handle proc receive work
+func ProcReceive(ctx *context.PrivateContext, opts *private.HookOptions) []private.HookProcReceiveRefResult {
 	// TODO: Add more options?
 	var (
 		topicBranch string